package com.ruoyi.brewery.service;

import java.util.List;
import com.ruoyi.common.core.domain.entity.WyBreweryUserRole;

/**
 * 品牌方用户和角色关联Service接口
 * 
 * @author ruoyi
 * @date 2024-12-22
 */
public interface IWyBreweryUserRoleService 
{
    /**
     * 查询品牌方用户和角色关联
     * 
     * @param userId 品牌方用户和角色关联主键
     * @return 品牌方用户和角色关联
     */
    public WyBreweryUserRole selectWyBreweryUserRoleByUserId(Long userId);

    /**
     * 查询品牌方用户和角色关联列表
     * 
     * @param wyBreweryUserRole 品牌方用户和角色关联
     * @return 品牌方用户和角色关联集合
     */
    public List<WyBreweryUserRole> selectWyBreweryUserRoleList(WyBreweryUserRole wyBreweryUserRole);

    /**
     * 新增品牌方用户和角色关联
     * 
     * @param wyBreweryUserRole 品牌方用户和角色关联
     * @return 结果
     */
    public int insertWyBreweryUserRole(WyBreweryUserRole wyBreweryUserRole);

    /**
     * 修改品牌方用户和角色关联
     * 
     * @param wyBreweryUserRole 品牌方用户和角色关联
     * @return 结果
     */
    public int updateWyBreweryUserRole(WyBreweryUserRole wyBreweryUserRole);

    /**
     * 批量删除品牌方用户和角色关联
     * 
     * @param userIds 需要删除的品牌方用户和角色关联主键集合
     * @return 结果
     */
    public int deleteWyBreweryUserRoleByUserIds(Long[] userIds);

    /**
     * 删除品牌方用户和角色关联信息
     * 
     * @param userId 品牌方用户和角色关联主键
     * @return 结果
     */
    public int deleteWyBreweryUserRoleByUserId(Long userId);
}
